.. module:: enaml.widgets.stack_item

========================
enaml.widgets.stack_item
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    StackItem


.. autoclass:: StackItem
